@@ -1,5 +1,5 @@
 """
-   Copyright 2020 Ian Housman
+   Copyright 2021 Ian Housman
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
@@ -533,6 +533,66 @@ def LT_VT_vertStack_multBands(img, verdet_or_landtrendr, multBy):
               .copyProperties(img)
     return out
 
+#Simplified method to convert LANDTRENDR stack to annual collection of
+#Duration, fitted, magnitude, slope, and diff
+#Improved handling of start year delay found in older method
+def simpleLTFit(ltStack,startYear,endYear,indexName = ''):
+  indexName = ee.String(indexName)
+
+  #Separate years and fitted values of vertices
+  yrs = ltStack.select('yrs_.*').selfMask()
+  fit = ltStack.select('fit_.*').updateMask(yrs.mask())
+  
+  #Find the first and last vertex years
+  isStartYear = yrs.reduce(ee.Reducer.firstNonNull())
+  isEndYear = yrs.reduce(ee.Reducer.lastNonNull())  
+  blankMask = yrs.gte(100000)
+  
+  #Iterate across each year to find the values for that year
+  def getYearValues(yr):
+    yr = ee.Number(yr)
+    
+    # Find the segment the year belongs to
+    # Handle whether the year is the same as the first vertex year
+    startYrMask =  blankMask
+    startYrMask = startYrMask.where(isStartYear.eq(yr), yrs.lte(yr))
+    startYrMask = startYrMask.where(isStartYear.lt(yr), yrs.lt(yr))
+    
+    # Handle whether the year is the same as the last vertex year
+    endYrMask =  blankMask
+    endYrMask = endYrMask.where(isStartYear.eq(yr),yrs.gt(yr))
+    endYrMask = endYrMask.where(isStartYear.lt(yr),yrs.gte(yr))
+
+    # Get fitted values for the vertices segment the year is within
+    fitStart = fit.updateMask(startYrMask).reduce(ee.Reducer.lastNonNull())
+    fitEnd = fit.updateMask(endYrMask).reduce(ee.Reducer.firstNonNull())
+    
+    # Get start and end year for the vertices segment the year is within
+    yearStart = yrs.updateMask(startYrMask).reduce(ee.Reducer.lastNonNull())
+    yearEnd = yrs.updateMask(endYrMask).reduce(ee.Reducer.firstNonNull())
+    
+    # Get the difference and duration of the segment
+    segDiff = fitEnd.subtract(fitStart)
+    segDur = yearEnd.subtract(yearStart)
+    
+    #Get the varius annual derivatives
+    tDiff = ee.Image(yr).subtract(yearStart)
+    segSlope = segDiff.divide(segDur)
+    fitDiff = segSlope.multiply(tDiff)
+    fitted = fitStart.add(fitDiff)
+    
+    formatted = segDur.addBands(fitted)\
+                .addBands(segDiff)\
+                .addBands(segSlope)\
+                .addBands(fitDiff)\
+                .rename([indexName.cat('_LT_dur'), indexName.cat('_LT_fitted'), indexName.cat('_LT_mag'), indexName.cat('_LT_slope'), indexName.cat('_LT_diff')])\
+                .set('system:time_start',ee.Date.fromYMD(yr,6,1).millis())
+
+    return formatted
+
+  out = ee.ImageCollection(ee.List.sequence(startYear,endYear).map(lambda yr: getYearValues(yr)))
+  return out
+
 # Function to parse stack from LANDTRENDR or VERDET into image collection
 # July 2019 LSC: multiply(distDir) and multiply(10000) now take place outside of this function,
 # but must be done BEFORE stack is passed to this function
@@ -1559,10 +1619,10 @@ def simpleCCDCPrediction(img,timeBandName,whichHarmonics,whichBands):
   #Iterate across each band and predict value
   def predHelper(bn):
     bn = ee.String(bn);
-    return ee.Image([intercepts.select(bn.cat('.*')),
-                    slopes.select(bn.cat('.*')),
-                    sins.select(bn.cat('.*')).multiply(sinHarm),
-                    coss.select(bn.cat('.*')).multiply(cosHarm)
+    return ee.Image([intercepts.select(bn.cat('_.*')),
+                    slopes.select(bn.cat('_.*')),
+                    sins.select(bn.cat('_.*')).multiply(sinHarm),
+                    coss.select(bn.cat('_.*')).multiply(cosHarm)
                     ]).reduce(ee.Reducer.sum());
   predicted = ee.ImageCollection(list(map(predHelper,whichBands))).toBands().rename(outBns)
   return img.addBands(predicted)
@@ -1607,7 +1667,7 @@ def getCCDCSegCoeffs(timeImg,ccdcImg,fillGaps):
   
   
   #Set up a mask for segments that the time band intersects
-  tMask = tStarts.lte(timeImg).And(tEnds.gt(timeImg)).arrayRepeat(1,1).arrayRepeat(2,1)
+  tMask = tStarts.lt(timeImg).And(tEnds.gte(timeImg)).arrayRepeat(1,1).arrayRepeat(2,1)
   coeffs = coeffs.arrayMask(tMask).arrayProject([2,1]).arrayTranspose(1,0).arrayFlatten([bns,harmonicTag])
   
   #If time band doesn't intersect any segments, set it to null
@@ -1615,6 +1675,75 @@ def getCCDCSegCoeffs(timeImg,ccdcImg,fillGaps):
   
   return timeImg.addBands(coeffs)
 
+###################################################################################
+# Functions to get yearly ccdc coefficients.
+# 
+# Get CCDC coefficients for each year.
+# yearStartMonth and yearStartDay are the date that you want the CCDC "year" to start at. This is mostly important for Annualized CCDC.
+# For LCMS, this is Sept. 1. So any change that occurs before Sept 1 in that year will be counted in that year, and Sept. 1 and after
+# will be counted in the following year.
+def annualizeCCDC(ccdcImg, startYear, endYear, startJulian, endJulian, yearStartMonth, yearStartDay, tEndExtrapolationPeriod):
+  # Create image collection of images with the proper time stamp as well as a 'year' band with the year fraction.
+  timeImgs = getTimeImageCollection(startYear, endYear, startJulian ,endJulian, 1, yearStartMonth, yearStartDay)
+
+  # If selected, add a constant amount of time to last end segment to make sure the last year is annualized correctly.
+  # tEndExtrapolationPeriod should be a fraction of a year.
+  finalTEnd = ccdcImg.select('tEnd')
+  finalTEnd = finalTEnd.arraySlice(0,-1,None).rename('tEnd').arrayGet(0).add(tEndExtrapolationPeriod).toArray(0)
+  tEnds = ccdcImg.select('tEnd')
+  tEnds = tEnds.arraySlice(0,0,-1).arrayCat(finalTEnd,0).rename('tEnd')
+  keepBands = ccdcImg.bandNames().remove('tEnd')
+  ccdcImg = ccdcImg.select(keepBands).addBands(tEnds)
+
+  # Loop through time image collection and grab the correct CCDC coefficients
+  annualSegCoeffs = timeImgs.map(lambda img: getCCDCSegCoeffs(img,ccdcImg,True))
+  return annualSegCoeffs
+
+
+# Using annualized time series, get fitted values and slopes from fitted values.
+def getFitSlopeCCDC(annualSegCoeffs, startYear, endYear):
+  # Predict across each time image
+  whichBands = ee.Image(annualSegCoeffs.first()).select(['.*_INTP']).bandNames().map(lambda bn: ee.String(bn).split('_').get(0))
+  whichBands = ee.Dictionary(whichBands.reduce(ee.Reducer.frequencyHistogram())).keys()
+  fitted = annualSegCoeffs.map(lambda img: simpleCCDCPredictionAnnualized(img,'year',whichBands))
+  
+  # Get back-casted slope using the fitted values
+  diff = ee.ImageCollection(ee.List.sequence(ee.Number(startYear).add(ee.Number(1)), endYear).map(lambda rightYear: yearlySlope(rightYear, fitted)))
+  
+  # Rename bands
+  bandNames = diff.first().bandNames()
+  newBandNames = bandNames.map(lambda name: ee.String(name).replace('coefs','CCDC'))
+  diff = diff.select(bandNames, newBandNames)
+
+  return diff
+
+def yearlySlope(rightYear, fitted):
+  leftYear = ee.Number(rightYear).subtract(1)
+  rightFitted = ee.Image(fitted.filter(ee.Filter.calendarRange(rightYear, rightYear, 'year')).first())
+  leftFitted = ee.Image(fitted.filter(ee.Filter.calendarRange(leftYear, leftYear, 'year')).first())
+  slopeNames = rightFitted.select(['.*_fitted']).bandNames().map(lambda name: ee.String(ee.String(name).split('_fitted').get(0)).cat(ee.String('_fitSlope')))
+  slope = rightFitted.select(['.*_fitted']).subtract(leftFitted.select(['.*_fitted'])).rename(slopeNames)
+  return rightFitted.addBands(slope)
+
+def simpleCCDCPredictionAnnualized(img,timeBandName,whichBands):
+
+  # Pull out the time band in the yyyy.ff format
+  tBand = img.select([timeBandName])
+  
+  # Pull out the intercepts and slopes
+  intercepts = img.select(['.*_INTP'])
+  slopes = img.select(['.*_SLP']).multiply(tBand)
+  
+  # Set up final output band names
+  outBns = whichBands.map(lambda bn: ee.String(bn).cat('_CCDC_fitted'))
+  
+  # Iterate across each band and predict value
+  predicted = ee.ImageCollection(whichBands.map(lambda bn: ee.Image([intercepts.select(ee.String(bn).cat('_.*')),
+                    slopes.select(ee.String(bn).cat('_.*')),
+                    ]).reduce(ee.Reducer.sum())\
+              )).toBands().rename(outBns)
+  return img.addBands(predicted)
+
 ###################################################################################
 #Wrapper function for predicting CCDC across a set of time images
 def predictCCDC(ccdcImg,timeImgs,fillGaps,whichHarmonics):
@@ -1628,15 +1757,19 @@ def predictCCDC(ccdcImg,timeImgs,fillGaps,whichHarmonics):
 ###################################################################################
 #Function for getting a set of time images
 #This is generally used for methods such as CCDC
-def getTimeImageCollection(startYear,endYear,startJulian = 1,endJulian = 365,step = 0.1):
+# yearStartMonth and yearStartDay are the date that you want the CCDC "year" to start at. This is mostly important for Annualized CCDC.
+# For LCMS, this is Sept. 1. So any change that occurs before Sept 1 in that year will be counted in that year, and Sept. 1 and after
+# will be counted in the following year.
+def getTimeImageCollection(startYear, endYear, startJulian = 1, endJulian = 365, step = 0.1, yearStartMonth = 1, yearStartDay = 1):
   def getYrImage(n):
     n = ee.Number(n)
     img = ee.Image(n).float().rename(['year'])
     y = n.int16()
     fraction = n.subtract(y)
-    d = ee.Date.fromYMD(y,1,1).advance(fraction,'year').millis()
-    return img.set('system:time_start',d);
-  yearImages = ee.ImageCollection(ee.List.sequence(startYear,endYear,step).map(getYrImage))
+    d = ee.Date.fromYMD(y.subtract(ee.Number(1)),12,31).advance(fraction,'year').millis()
+    return img.set('system:time_start',d)
+  monthDayFraction = ee.Number.parse(ee.Date.fromYMD(startYear, yearStartMonth, yearStartDay).format('DDD')).divide(365)
+  yearImages = ee.ImageCollection(ee.List.sequence(ee.Number(startYear).add(monthDayFraction),ee.Number(endYear).add(monthDayFraction),step).map(getYrImage))
   return yearImages.filter(ee.Filter.calendarRange(startYear,endYear,'year'))\
                       .filter(ee.Filter.calendarRange(startJulian,endJulian))
 
@@ -1648,44 +1781,55 @@ def ccdcChangeDetection(ccdcImg,bandName):
   magKeys = ['.*_magnitude']
   tBreakKeys = ['tBreak']
   changeProbKeys = ['changeProb']
-  
+  changeProbThresh = 1
+
   #Pull out pieces from CCDC output
   magnitudes = ccdcImg.select(magKeys)
   breaks = ccdcImg.select(tBreakKeys)
   
   #Map.addLayer(breaks.arrayLength(0),{'min':1,'max':10});
-  #changeProbs = ccdcImg.select(changeProbKeys);
-  #changeMask = changeProbs.gte(changeProbThresh);
+  changeProbs = ccdcImg.select(changeProbKeys)
+  changeMask = changeProbs.gte(changeProbThresh)
   magnitudes = magnitudes.select(bandName + '.*')
 
   
   #Sort by magnitude and years
   breaksSortedByMag = breaks.arraySort(magnitudes)
   magnitudesSortedByMag = magnitudes.arraySort()
+  changeMaskSortedByMag = changeMask.arraySort(magnitudes)
   
   breaksSortedByYear = breaks.arraySort()
   magnitudesSortedByYear = magnitudes.arraySort(breaks)
+  changeMaskSortedByYear = changeMask.arraySort(breaks)
   
   #Get the loss and gain years and magnitudes for each sorting method
   highestMagLossYear = breaksSortedByMag.arraySlice(0,0,1).arrayFlatten([['loss_year']])
   highestMagLossMag = magnitudesSortedByMag.arraySlice(0,0,1).arrayFlatten([['loss_mag']])
-  highestMagLossYear = highestMagLossYear.updateMask(highestMagLossMag.lt(0))
-  highestMagLossMag = highestMagLossMag.updateMask(highestMagLossMag.lt(0))
+  highestMagLossMask = changeMaskSortedByMag.arraySlice(0,0,1).arrayFlatten([['loss_mask']])
+  
+  highestMagLossYear = highestMagLossYear.updateMask(highestMagLossMag.lt(0).And(highestMagLossMask))
+  highestMagLossMag = highestMagLossMag.updateMask(highestMagLossMag.lt(0).And(highestMagLossMask))
   
   highestMagGainYear = breaksSortedByMag.arraySlice(0,-1,None).arrayFlatten([['gain_year']])
   highestMagGainMag = magnitudesSortedByMag.arraySlice(0,-1,None).arrayFlatten([['gain_mag']])
-  highestMagGainYear = highestMagGainYear.updateMask(highestMagGainMag.gt(0));
-  highestMagGainMag = highestMagGainMag.updateMask(highestMagGainMag.gt(0));
+  highestMagGainMask = changeMaskSortedByMag.arraySlice(0,-1,None).arrayFlatten([['gain_mask']]);
+  
+  highestMagGainYear = highestMagGainYear.updateMask(highestMagGainMag.gt(0).And(highestMagGainMask));
+  highestMagGainMag = highestMagGainMag.updateMask(highestMagGainMag.gt(0).And(highestMagGainMask));
   
   mostRecentLossYear = breaksSortedByYear.arraySlice(0,0,1).arrayFlatten([['loss_year']])
   mostRecentLossMag = magnitudesSortedByYear.arraySlice(0,0,1).arrayFlatten([['loss_mag']])
-  mostRecentLossYear = mostRecentLossYear.updateMask(mostRecentLossMag.lt(0))
-  mostRecentLossMag = mostRecentLossMag.updateMask(mostRecentLossMag.lt(0))
+  mostRecentLossMask = changeMaskSortedByYear.arraySlice(0,0,1).arrayFlatten([['loss_mask']])
+  
+  mostRecentLossYear = mostRecentLossYear.updateMask(mostRecentLossMag.lt(0).And(mostRecentLossMask))
+  mostRecentLossMag = mostRecentLossMag.updateMask(mostRecentLossMag.lt(0).And(mostRecentLossMask))
 
   mostRecentGainYear = breaksSortedByYear.arraySlice(0,-1,None).arrayFlatten([['gain_year']])
   mostRecentGainMag = magnitudesSortedByYear.arraySlice(0,-1,None).arrayFlatten([['gain_mag']])
-  mostRecentGainYear = mostRecentGainYear.updateMask(mostRecentGainMag.gt(0))
-  mostRecentGainMag = mostRecentGainMag.updateMask(mostRecentGainMag.gt(0))
+  mostRecentGainMask = changeMaskSortedByYear.arraySlice(0,-1,None).arrayFlatten([['gain_mask']])
+  
+  mostRecentGainYear = mostRecentGainYear.updateMask(mostRecentGainMag.gt(0).And(mostRecentGainMask))
+  mostRecentGainMag = mostRecentGainMag.updateMask(mostRecentGainMag.gt(0).And(mostRecentGainMask))
   
   return {'mostRecent':{
     'loss':{'year':mostRecentLossYear,
